'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getRouteNameMap = getRouteNameMap;

var _reduxifyService = require('./reduxifyService');

var _reduxifyService2 = _interopRequireDefault(_reduxifyService);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Normalizes the routes argument for internal usage.
 *
 * @param {Object|Array|String} routes - The feathers services to reduxify. See below.
 * @returns {Object}
 */
function getRouteNameMap(routes) {
  if (typeof routes === 'string') {
    return _defineProperty({}, routes, routes);
  } else if (Array.isArray(routes)) {
    return routes.reduce(function (routeMap, route) {
      return Object.assign(routeMap, _defineProperty({}, route, route));
    }, {});
  }
  return routes;
}

/**
 * Create Redux actions and reducers for Feathers services.
 *
 * @param {Object} app - Feathers application instance
 * @param {Object|Array|String} routes - The feathers services to reduxify. See below.
 * @param {Object} options - See reduxifyService
 * @returns {Object} Each services' action creators.
 *
 */

exports.default = function (app, routes, options) {
  var routeNameMap = getRouteNameMap(routes);
  return Object.keys(routeNameMap).reduce(function (services, routeKey) {
    return Object.assign(services, _defineProperty({}, routeNameMap[routeKey], (0, _reduxifyService2.default)(app, routeKey, routeNameMap[routeKey], options)));
  }, {});
};