'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = reduxifyService;

var _reduxActions = require('redux-actions');

var _reduxifyServiceUtils = require('./reduxifyServiceUtils');

var _reducerForServiceMethod = require('./reducerForServiceMethod');

var _reducerForServiceMethod2 = _interopRequireDefault(_reducerForServiceMethod);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var defaults = {
  isError: 'isError',
  isLoading: 'isLoading',
  isSaving: 'isSaving',
  isFinished: 'isFinished',
  data: 'data',
  queryResult: 'queryResult',
  store: 'store',
  PENDING: 'PENDING',
  FULFILLED: 'FULFILLED',
  REJECTED: 'REJECTED'
};

/**
 * Build a Redux compatible wrapper around a Feathers service.
 *
 * @param {Object} app - the configured Feathers app
 * @param {String} route - the Feathers' route for the service.
 * @param {String} name - the serviceName by which the service is known on client. Default route.
 * @param {Object} options
 * @returns {{find: *, get: *, create: *, update: *, patch: *, remove: *, on: *, reducer: *}}
 */
function reduxifyService(app, route, name) {
  var options = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : {};

  var opts = Object.assign({}, defaults, options);
  var actionTypes = (0, _reduxifyServiceUtils.getActionTypes)(name);
  var service = app.service(route);

  if (!service) {
    throw Error('Feathers service \'' + route + '\' does not exist.');
  }

  return {
    find: (0, _reduxActions.createAction)(actionTypes.FIND, function (p) {
      return { promise: service.find(p), data: undefined };
    }),
    get: (0, _reduxActions.createAction)(actionTypes.GET, function (id, p) {
      return { promise: service.get(id, p) };
    }),
    create: (0, _reduxActions.createAction)(actionTypes.CREATE, function (d, p) {
      return { promise: service.create(d, p) };
    }),
    update: (0, _reduxActions.createAction)(actionTypes.UPDATE, function (id, d, p) {
      return { promise: service.update(id, d, p) };
    }),
    patch: (0, _reduxActions.createAction)(actionTypes.PATCH, function (id, d, p) {
      return { promise: service.patch(id, d, p) };
    }),
    remove: (0, _reduxActions.createAction)(actionTypes.REMOVE, function (id, p) {
      return { promise: service.remove(id, p) };
    }),
    reset: (0, _reduxActions.createAction)(actionTypes.RESET),
    store: (0, _reduxActions.createAction)(actionTypes.STORE, function (store) {
      return store;
    }),
    on: function on(event, data, fcn) {
      return function (dispatch, getState) {
        fcn(event, data, dispatch, getState);
      };
    },
    reducer: (0, _reduxActions.handleActions)(Object.assign({}, (0, _reducerForServiceMethod2.default)(actionTypes.FIND, true, true, opts), (0, _reducerForServiceMethod2.default)(actionTypes.GET, true, false, opts), (0, _reducerForServiceMethod2.default)(actionTypes.CREATE, false, false, opts), (0, _reducerForServiceMethod2.default)(actionTypes.UPDATE, false, false, opts), (0, _reducerForServiceMethod2.default)(actionTypes.PATCH, false, false, opts), (0, _reducerForServiceMethod2.default)(actionTypes.REMOVE, false, false, opts), (0, _reduxifyServiceUtils.reducerForReset)(actionTypes.RESET, opts), (0, _reduxifyServiceUtils.reducerForStore)(actionTypes.STORE, opts)), (0, _reduxifyServiceUtils.getDefaultState)(opts))
  };
}