'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getActionTypes = getActionTypes;
exports.getDefaultState = getDefaultState;
exports.reducerForReset = reducerForReset;
exports.reducerForStore = reducerForStore;

var _timm = require('timm');

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * Creates an object of action types for a given service.
 *
 * @param {String} name - the serviceName by which the service is known on client. Default route.
 * @returns {{find: *, get: *, create: *, update: *, patch: *, remove: *, on: *, reducer: *}}
 */
function getActionTypes(serviceName) {
  var SERVICE_NAME = 'SERVICES_' + serviceName.toUpperCase() + '_';
  return {
    FIND: SERVICE_NAME + 'FIND',
    GET: SERVICE_NAME + 'GET',
    CREATE: SERVICE_NAME + 'CREATE',
    UPDATE: SERVICE_NAME + 'UPDATE',
    PATCH: SERVICE_NAME + 'PATCH',
    REMOVE: SERVICE_NAME + 'REMOVE',
    RESET: SERVICE_NAME + 'RESET',
    STORE: SERVICE_NAME + 'STORE'
  };
}

/**
 * Creates an initial state object for a feathers service.
 *
 * @param {Object} options
 * @returns {Object} - default state
 */
function getDefaultState(opts) {
  var _ref;

  return _ref = {}, _defineProperty(_ref, opts.isError, null), _defineProperty(_ref, opts.isLoading, false), _defineProperty(_ref, opts.isSaving, false), _defineProperty(_ref, opts.isFinished, false), _defineProperty(_ref, opts.data, null), _defineProperty(_ref, opts.queryResult, null), _defineProperty(_ref, opts.store, null), _ref;
}

/**
 * Reset status if no promise is pending
 *
 * @param {String} actionName - name of redux action
 * @param {Object} opts
 * @returns {Object}
 */
function reducerForReset(actionName, opts) {
  return _defineProperty({}, actionName, function (state, action) {
    var _merge;

    if (state[opts.isLoading] || state[opts.isSaving]) {
      return state;
    }
    return (0, _timm.merge)(state, (_merge = {}, _defineProperty(_merge, opts.isError, null), _defineProperty(_merge, opts.isLoading, false), _defineProperty(_merge, opts.isSaving, false), _defineProperty(_merge, opts.isFinished, false), _defineProperty(_merge, opts.data, null), _defineProperty(_merge, opts.queryResult, action.payload ? state[opts.queryResult] : null), _defineProperty(_merge, opts.store, null), _merge));
  });
}

/**
 * Update store
 *
 * @param {String} actionName - name of redux action
 * @param {Object} opts
 * @returns {Object}
 *
 */
function reducerForStore(actionName, opts) {
  return _defineProperty({}, actionName, function (state, action) {
    return (0, _timm.merge)(state, _defineProperty({}, opts.store, action.payload));
  });
}